package fr.inria.phoenix.diasuite.framework.context.analysis;

import java.io.Serializable;

/**
 * An object to store a value published by the context <code>Analysis</code>.
 * <p>
 * Comparatively analyze efficiencies and detect users needing an audit
 *
 * <pre>
 * context Analysis as String {
 * 	when provided tickHour from Clock
 * 		get AverageEfficiency, ReferenceEfficiency
 * 		maybe publish;
 * }
 * </pre>
 */
public final class AnalysisValue implements Serializable {
    private static final long serialVersionUID = 0;
    
    private java.lang.String value;
    
    /**
     * Get the value of the context <code>Analysis</code>
     * 
     * <p>
     * Comparatively analyze efficiencies and detect users needing an audit
     * 
     * @return the value of the context <code>Analysis</code>
     */
    public java.lang.String value() {
        return value;
    }
    
    public AnalysisValue(java.lang.String value) {
        this.value = value;
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((value == null) ? 0 : value.hashCode());
        return result;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        AnalysisValue other = (AnalysisValue) obj;
        if (value == null) {
            if (other.value != null)
                return false;
        } else if (!value.equals(other.value))
            return false;
        return true;
    }
}
