package fr.inria.phoenix.diasuite.framework.context.efficiency;

import java.io.Serializable;

/**
 * An object to store a value published by the context <code>Efficiency</code>.
 * <p>
 * Compute instant efficiency for each heating measurement
 *
 * <pre>
 * context Efficiency as EfficiencySample {
 * 	when provided currentHeatingConsumption from HeatingMeter
 * 		get targetTemperature from Thermostat,
 * 			temperature from TemperatureSensor
 * 		always publish;
 * }
 * </pre>
 */
public final class EfficiencyValue implements Serializable {
    private static final long serialVersionUID = 0;
    
    private fr.inria.phoenix.diasuite.framework.datatype.efficiencysample.EfficiencySample value;
    
    /**
     * Get the value of the context <code>Efficiency</code>
     * 
     * <p>
     * Compute instant efficiency for each heating measurement
     * 
     * @return the value of the context <code>Efficiency</code>
     */
    public fr.inria.phoenix.diasuite.framework.datatype.efficiencysample.EfficiencySample value() {
        return value;
    }
    
    public EfficiencyValue(fr.inria.phoenix.diasuite.framework.datatype.efficiencysample.EfficiencySample value) {
        this.value = value;
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((value == null) ? 0 : value.hashCode());
        return result;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        EfficiencyValue other = (EfficiencyValue) obj;
        if (value == null) {
            if (other.value != null)
                return false;
        } else if (!value.equals(other.value))
            return false;
        return true;
    }
}
