package fr.inria.phoenix.diasuite.framework.context.referenceefficiency;

import fr.inria.diagen.core.ServiceConfiguration;
import fr.inria.diagen.core.exception.InvocationException;
import fr.inria.diagen.core.network.RemoteServiceInfo;
import fr.inria.diagen.core.service.local.Service;
import fr.inria.diagen.core.service.proxy.Proxy;

import fr.inria.phoenix.diasuite.framework.context.efficiency.EfficiencyValue;

/**
 * Compute the reference efficiency as the average of all users
 * 
 * <pre>
 * context ReferenceEfficiency as Float {
 * 	when provided Efficiency no publish;
 * 	when required;
 * }
 * </pre>
 */
@SuppressWarnings("all")
public abstract class AbstractReferenceEfficiency extends Service {
    
    public AbstractReferenceEfficiency(ServiceConfiguration serviceConfiguration) {
        super("/Context/ReferenceEfficiency/", serviceConfiguration);
    }
    
    // Methods from the Service class
    @Override
    protected final void internalPostInitialize() {
        subscribeValue("efficiency", "/Context/Efficiency/"); // subscribe to Efficiency context
        postInitialize();
    }
    
    @Override
    public final void valueReceived(java.util.Map<String, Object> properties, RemoteServiceInfo source, String eventName, Object value, Object... indexes) {
        if (eventName.equals("efficiency") && source.isCompatible("/Context/Efficiency/")) {
            EfficiencyValue efficiencyValue = new EfficiencyValue((fr.inria.phoenix.diasuite.framework.datatype.efficiencysample.EfficiencySample) value);
            
            onEfficiency(efficiencyValue);
        }
    }
    
    @Override
    public final Object getValueCalled(java.util.Map<String, Object> properties, RemoteServiceInfo source, String valueName,
            Object... indexes) throws Exception {
        if (valueName.equals("referenceEfficiency")) {
            return getValue();
        }
        throw new InvocationException("Unsupported method call: " + valueName);
    }
    // End of methods from the Service class
    
    // Code relative to the return value of the context
    private java.lang.Float contextValue;
    
    private void setReferenceEfficiency(java.lang.Float newContextValue) {
        contextValue = newContextValue;
        getProcessor().publishValue(getOutProperties(), "referenceEfficiency", newContextValue);
    }
    
    /**
     * Get the last value of the context
     * 
     * @return the latest value published by the context
     */
    protected final java.lang.Float getLastValue() {
        return contextValue;
    }
    // End of code relative to the return value of the context
    
    // Interaction contract implementation
    /**
     * This method is called when the <code>Efficiency</code> context publishes a value.
     * 
     * <pre>
     * when provided Efficiency no publish;
     * </pre>
     * 
     * @param efficiencyValue the value of the <code>Efficiency</code> context.
     */
    protected abstract void onEfficiency(EfficiencyValue efficiencyValue);
    
    /**
     * This method is called when the value of this context is required.
     * 
     * <pre>
     * when required;
     * </pre>
     * 
     * @return the value of the context to return
     */
    protected abstract java.lang.Float getValue();
    
    // End of interaction contract implementation
}
