package fr.inria.phoenix.diasuite.framework.context.window;

import java.io.Serializable;

/**
 * An object to store a value published by the context <code>Window</code>.
 * <p>
 * Cut/restart heating when window is open/closed
 *
 * <pre>
 * context Window as Boolean indexed by user as String {
 * 	when provided state from ContactSensor
 * 	get status from Thermostat maybe publish;
 * }
 * </pre>
 */
public final class WindowValue implements Serializable {
    private static final long serialVersionUID = 0;
    
    private java.lang.Boolean value;
    
    /**
     * Get the value of the context <code>Window</code>
     * 
     * <p>
     * Cut/restart heating when window is open/closed
     * 
     * @return the value of the context <code>Window</code>
     */
    public java.lang.Boolean value() {
        return value;
    }
    
    private WindowIndices indices;
    
    /**
     * Get the value of the indices of the context <code>Window</code>
     * 
     * @return the value of the indices
     */
    public WindowIndices indices() {
        return indices;
    }
    
    public WindowValue(java.lang.Boolean value, WindowIndices indices) {
        this.value = value;
        this.indices = indices;
    }
    
    public WindowValue(java.lang.Boolean value,
            java.lang.String user) {
        this.value = value;
        this.indices = new WindowIndices(user);
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((value == null) ? 0 : value.hashCode());
        result = prime * result + ((indices == null) ? 0 : indices.hashCode());
        return result;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        WindowValue other = (WindowValue) obj;
        if (value == null) {
            if (other.value != null)
                return false;
        } else if (!value.equals(other.value))
            return false;
        if (indices == null) {
            if (other.indices != null)
                return false;
        } else if (!indices.equals(other.indices))
            return false;
        return true;
    }
}
