package fr.inria.phoenix.scenario.heatingmonitor.impl.context;

import java.util.List;

import fr.inria.diagen.core.ServiceConfiguration;
import fr.inria.phoenix.diasuite.framework.context.analysis.AbstractAnalysis;
import fr.inria.phoenix.diasuite.framework.datatype.efficiencysample.EfficiencySample;
import fr.inria.phoenix.diasuite.framework.device.clock.TickHourFromClock;

/* Comparatively analyze efficiencies and detect users needing an audit.
 * The implementation of the Analysis context
 * @see fr.inria.phoenix.diasuite.framework.context.analysis.AbstractAnalysis
 */
public class Analysis extends AbstractAnalysis {

	public Analysis(ServiceConfiguration serviceConfiguration) {
		super(serviceConfiguration);
	}

	@Override
	protected AnalysisValuePublishable onTickHourFromClock(
			TickHourFromClock tickHourFromClock,
			DiscoverForTickHourFromClock discover) {
		List<EfficiencySample> effs = discover.averageEfficiency();
		Float ref = discover.referenceEfficiency();
		// Look for the the first very inefficient user
		for (EfficiencySample eff : effs) {
			if ((eff.getEfficiency() / ref) < 0.5) // worse than half the
													// reference
				return new AnalysisValuePublishable(eff.getUser(), true);
		}
		// No flagrant inefficiency found, do nothing
		return new AnalysisValuePublishable(null, false);
	}
}
