package fr.inria.phoenix.scenario.heatingmonitor.impl.context;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javafx.util.Pair;
import fr.inria.diagen.core.ServiceConfiguration;
import fr.inria.phoenix.diasuite.framework.context.averageefficiency.AbstractAverageEfficiency;
import fr.inria.phoenix.diasuite.framework.context.efficiency.EfficiencyValue;
import fr.inria.phoenix.diasuite.framework.datatype.efficiencysample.EfficiencySample;

/* Compute the average efficiency for each user.
 * The implementation of the AverageEfficiency context
 * @see fr.inria.phoenix.diasuite.framework.context.averageefficiency.AbstractAverageEfficiency
 */
public class AverageEfficiency extends AbstractAverageEfficiency {
	/* Map associating each user U to a pair <N, Eff>, where:
	 * - N:int is the number of heating measurements seen for user U
	 * - Eff:float is the average efficiency for user U
	 */
    private Map<String,Pair<Integer,Float>> efficiency = new HashMap<String,Pair<Integer,Float>>();
	
    public AverageEfficiency(ServiceConfiguration serviceConfiguration) {
        super(serviceConfiguration);
    }
    
    /* Given a heating measurement, update the efficiency average for that user.
     * @see fr.inria.phoenix.diasuite.framework.context.averageefficiency.AbstractAverageEfficiency#onEfficiency(EfficiencyValue)
     */
    @Override
    protected void onEfficiency(EfficiencyValue efficiencyValue) {
    	String user = efficiencyValue.value().getUser();
    	Float e1 = efficiencyValue.value().getEfficiency();
    	if(efficiency.containsKey(user)) {
    		int n = efficiency.get(user).getKey();
    		Float e0 = efficiency.get(user).getValue();
    		efficiency.put(user, new Pair<Integer,Float>(n+1, (e0 * n + e1) / (n + 1)));
    	} else efficiency.put(user, new Pair<Integer,Float>(1, e1));
    	System.out.println(user+":<"+efficiency.get(user).getKey()+":"+efficiency.get(user).getValue()+">");
    }

    /* Translate the map user:<n,efficiency> to a list of averages <user,efficiency>.
     * @see fr.inria.phoenix.diasuite.framework.context.averageefficiency.AbstractAverageEfficiency#getValue()
     */
	@Override
	protected List<EfficiencySample> getValue() {
		List<EfficiencySample> effList = new ArrayList<EfficiencySample>();
    	for(String aUser: efficiency.keySet()) {
    		effList.add(new EfficiencySample(efficiency.get(aUser).getValue(), aUser));
    	}
    	System.out.println("get: size="+effList.size());
    	for(EfficiencySample eff: effList) {
    		System.out.println("<"+eff.getUser()+":"+eff.getEfficiency()+">");
    	}
    	return effList;
	}
}
