package fr.inria.phoenix.scenario.heatingmonitor.impl.context;

import fr.inria.diagen.core.ServiceConfiguration;
import fr.inria.phoenix.diasuite.framework.context.efficiency.AbstractEfficiency;
import fr.inria.phoenix.diasuite.framework.datatype.efficiencysample.EfficiencySample;
import fr.inria.phoenix.diasuite.framework.datatype.temperature.Temperature;
import fr.inria.phoenix.diasuite.framework.device.heatingmeter.CurrentHeatingConsumptionFromHeatingMeter;

/* Compute instant efficiency for each heating measurement.
 * The implementation of the Efficiency context
 * @see fr.inria.phoenix.diasuite.framework.context.efficiency.AbstractEfficiency
 */
public class Efficiency extends AbstractEfficiency {
    
    public Efficiency(ServiceConfiguration serviceConfiguration) {
        super(serviceConfiguration);
    }
    
    /* Example of formula for computing the efficiency of heating: 
     * - proportional to the temperature difference to compensate
     * - inversely proportional to the heating effort
     */
    private static Float efficiency(Float target, Float outside, Float heating) {
    	if(heating == 0) return (float)1; // not heating => efficiency is perfect
    	if(target < outside) // useless to heat, should open the window!
    		return (float)0.0; // heating => efficiency is zero!
    	return (target - outside) / heating;
    }
    
    /* Compute instant efficiency for each heating measurement.
     * @see fr.inria.phoenix.diasuite.framework.context.efficiency.AbstractEfficiency#onCurrentHeatingConsumptionFromHeatingMeter(CurrentHeatingConsumptionFromHeatingMeter, DiscoverForCurrentHeatingConsumptionFromHeatingMeter)
     */
    @Override
    protected EfficiencySample onCurrentHeatingConsumptionFromHeatingMeter(
    		CurrentHeatingConsumptionFromHeatingMeter currentHeatingConsumptionFromHeatingMeter,
    		DiscoverForCurrentHeatingConsumptionFromHeatingMeter discover) {
    	String measure = currentHeatingConsumptionFromHeatingMeter.value().getState();
    	Float heating = Float.valueOf(measure);
    	String user = currentHeatingConsumptionFromHeatingMeter.sender().user();
    	Temperature outsideTemperature = 
    			discover.temperatureSensors().anyOne().getTemperature();
    	Temperature targetTemperature =
    			discover.thermostats().whereUser(user).anyOne().getTargetTemperature();
    	Float e = efficiency(targetTemperature.getValue(), 
    			outsideTemperature.getValue(),
    			heating);
    	System.out.println("eff="+e+",user="+user);
    	return new EfficiencySample(e, user);
    }
}
